==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/TRANSACTIONLINEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINENUM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "transactionlinenum"
})
@XmlRootElement(name = "TRANSACTIONLINEID")
public class TRANSACTIONLINEID {

    @XmlElement(name = "TRANSACTIONID", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "TRANSACTIONLINENUM")
    protected Long transactionlinenum;

    /**
     * Obtient la valeur de la propriété transactionid.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Définit la valeur de la propriété transactionid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Obtient la valeur de la propriété transactionlinenum.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRANSACTIONLINENUM() {
        return transactionlinenum;
    }

    /**
     * Définit la valeur de la propriété transactionlinenum.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRANSACTIONLINENUM(Long value) {
        this.transactionlinenum = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/TRANSACTIONLINEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINENUM" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "transactionlinenum"
})
@XmlRootElement(name = "TRANSACTIONLINEID")
public class TRANSACTIONLINEID {

    @XmlElement(name = "TRANSACTIONID", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "TRANSACTIONLINENUM")
    protected Long transactionlinenum;

    /**
     * Gets the value of the transactionid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Sets the value of the transactionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Gets the value of the transactionlinenum property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRANSACTIONLINENUM() {
        return transactionlinenum;
    }

    /**
     * Sets the value of the transactionlinenum property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRANSACTIONLINENUM(Long value) {
        this.transactionlinenum = value;
    }

}
